==> aiida-castep-0.3.2.tar.gz: aiida-castep-0.3.2/aiida_castep/cmdline/usp_cmd.py <==
"""
Commandline plugin module for aiida CASTEP plugin
"""
from __future__ import print_function
import click

from aiida.cmdline.commands import data_cmd
from aiida.cmdline.dbenv_lazyloading import load_dbenv_if_not_loaded


@data_cmd.group('castep-usp')
def usp_cmd():
    """Commandline interface for working with UspData"""
    pass


@usp_cmd.command(name="listfamilies")
@click.option(
    '--element',
    '-e',
    multiple=True,
    help=
    "Show families contenting this element only. Can be passed multiple times")
@click.option('--with_description', '-d', is_flag=True)
def listfamilies(element, with_description):
    """List avaliable UspData families"""
    load_dbenv_if_not_loaded()
    from aiida.orm import QueryBuilder
    from aiida_castep.data.usp import USPGROUP_TYPE
    from aiida.orm import DataFactory, Group
    UspData = DataFactory("castep.uspdata")
    q = QueryBuilder()
    q.append(UspData, tag="uspdata")
    if element:
        q.add_filter("uspdata", {"attributes.element": {'in': element}})
    q.append(
        Group,
        tag='group',
        group_of=UspData,
        filters={'type': USPGROUP_TYPE},
        project=['name', 'description'])
    q.distinct()
    if q.count() > 0:
        for res in q.dict():
            group_name = res.get("group").get("name")
            group_desc = res.get("group").get("description")
            # Count the number of pseudos in this group
            q = QueryBuilder()
            q.append(
                Group, tag='thisgroup', filters={"name": {
                    'like': group_name
                }})
            q.append(UspData, project=["id"], member_of='thisgroup')

            if with_description:
                description_string = ": {}".format(group_desc)
            else:
                description_string = ""

            click.echo("* {} [{} pseudos]{}".format(group_name, q.count(),
                                                    description_string))

    else:
        click.echo("No valid USP pseudopotential family found.")

==> aiida-castep-1.0.0b1.tar.gz: aiida-castep-1.0.0b1/aiida_castep/cmdline/usp_cmd.py <==
"""
Commandline plugin module for aiida CASTEP plugin
"""
from __future__ import print_function
from __future__ import absolute_import
import click

from aiida.cmdline.commands.cmd_data import verdi_data


@verdi_data.group('castep-usp')
def usp_cmd():
    """Commandline interface for working with UspData"""
    pass


@usp_cmd.command(name="listfamilies")
@click.option(
    '--element',
    '-e',
    multiple=True,
    help=
    "Show families contenting this element only. Can be passed multiple times")
@click.option('--with_description', '-d', is_flag=True)
def listfamilies(element, with_description):
    """List avaliable UspData families"""
    from aiida.orm import QueryBuilder, Group
    from aiida_castep.data.usp import USPGROUP_TYPE
    from aiida.plugins import DataFactory
    UspData = DataFactory("castep.uspdata")
    q = QueryBuilder()
    q.append(UspData, tag="uspdata")
    if element:
        q.add_filter("uspdata", {"attributes.element": {'in': element}})
    q.append(
        Group,
        tag='group',
        with_node=UspData,
        filters={'type_string': USPGROUP_TYPE},
        project=['label', 'description'])
    q.distinct()
    if q.count() > 0:
        for res in q.dict():
            group_label = res.get("group").get("label")
            group_desc = res.get("group").get("description")
            # Count the number of pseudos in this group
            q = QueryBuilder()
            q.append(
                Group,
                tag='thisgroup',
                filters={"label": {
                    'like': group_label
                }})
            q.append(UspData, project=["id"], member_of='thisgroup')

            if with_description:
                description_string = ": {}".format(group_desc)
            else:
                description_string = ""

            click.echo("* {} [{} pseudos]{}".format(group_label, q.count(),
                                                    description_string))

    else:
        click.echo("No valid USP pseudopotential family found.")
